# This file is part of barrioSquare.
#
# barrioSquare is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# barrioSquare is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with barrioSquare. If not, see <http://www.gnu.org/licenses/>.
# or write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

# GOOGLE_MAPS_API_KEY = 'ABQIAAAApZ2euq0Rw9q9gnvrFpM9exTnaMynjZlWua31ZRN9Bu7KwLftLRQ43gnDTGdinhoU7RuKLZRQxMKcVg'
GOOGLE_MAPS_API_KEY = ''
VERSION_STRING = 'barriosquare 0.3.2'
SHORT_VERSION_STRING = '0.3.2'
# key and secret granted by the service provider for this consumer application - same as the MockOAuthDataStore
CONSUMER_KEY = '73da08e67b46cb1dc10fd43ea813071104af9fe79'
CONSUMER_SECRET = 'c9fadf4a225e74d907053aecd12f23d5'
TWITTER_CONSUMER_KEY = 'dcfjDyRq44d5AcVnFG5TgA'
TWITTER_CONSUMER_SECRET = 'iOdH21SjnN5CQWDXbsiFgiIjqqMrvva03OnpvmmS0'
SERVER = 'foursquare.com'
PORT = 80
API_PREFIX_URL = 'http://api.foursquare.com/v1/'
AUTHORIZATION_EXCHANGE_URL = 'http://api.foursquare.com/v1/authexchange'
REQUEST_TOKEN_URL = 'http://foursquare.com/oauth/request_token'
ACCESS_TOKEN_URL = 'http://foursquare.com/oauth/access_token'
AUTHORIZATION_URL = 'http://foursquare.com/oauth/authorize'
VENUE_URL = 'http://foursquare.com/venue/'
CALLBACK_URL = 'http://chilitechno.com/fster'
RESOURCE_URL = 'http://chilitechno.com/fster'
GET_LOCATION_SCRIPT = '/opt/barriosquare/get-location.py'
APP_DIRECTORY = '/opt/barriosquare/'

